#' Middle Earth troll data (single-season example with covariates)
#'
#' Most of what is known of Middle Earth (a.k.a. Arda) was documented by J.R.R.
#' Tolkien. Time is recorded in "Valian years", which measure the passage of
#' time since immortal spirits arrived on Arda.
#'
#' @name trolls
#' @docType data
#' @keywords datasets
#' @description troll data in "long" format for data-wrangling
#' @format data-framewith 2000 rows and 5 columns
#' \itemize{369236923
#' { data.frame:	2000 obs. of  5 variables:}
#' { ValianDate: chr  "1201/01/10" "1201/01/11" "1202/01/10" "1202/01/11" ...}
#' { site      : chr  "Arda1" "Arda1" "Arda1" "Arda1" ...}
#' { detection : int  0 0 0 0 0 0 0 0 0 0 ...}
#' { temp      : num  20.5 21 21 19.7 20.1 ...}
#' { observer  : chr  "Legolas" "Gollum" "Gollum" "Aragorn" ...}
#' \item{ observer   : chr  "Legolas" "Legolas" "Gollum" "Gollum" ...}
#' }
NULL

#' Middle Earth troll data (single-season example with covariates)
#'
#' Most of what is known of Middle Earth (a.k.a. Arda) was documented by J.R.R.
#' Tolkien. Time is recorded in "Valian years", which measure the passage of
#' time since immortal spirits arrived on Arda.
#'
#' @name trolls_ss
#' @docType data
#' @keywords datasets
#' @format data-framewith 375 rows and 15 columns
#' \itemize{
#' \item{ siteID     : int  1085441 1085441 1085441 1085441 1085441 985373 985373 985373 985373 985373 ...}
#' \item{ ValianDate : chr  "1200/01/10" "1200/01/11" "1200/01/12" "1200/01/13" ...}
#' \item{ region     : chr  "Arda" "Arda" "Arda" "Arda" ...}
#' \item{ detection  : int  0 1 1 0 0 0 0 1 0 1 ...}
#' \item{ city       : int  0 0 0 0 0 0 0 0 0 0 ...}
#' \item{ hill       : chr  "Y" "Y" "Y" "Y" ...}
#' \item{ river      : num  0 0 0 0 0 0.03 0.03 0.03 0.03 0.03 ...}
#' \item{ forest     : num  0 0 0 0 0 0.1 0.1 0.1 0.1 0.1 ...}
#' \item{ wetland    : num  0 0 0 0 0 0.007 0.007 0.007 0.007 0.007 ...}
#' \item{ hill15     : num  0.443 0.443 0.443 0.443 0.443 0.083 0.083 0.083 0.083 0.083 ...}
#' \item{ stonefields: int  0 0 0 0 0 0 0 0 0 0 ...}
#' \item{ northing   : num  576319 576319 576319 576319 576319 ...}
#' \item{ random     : num  0.838 0.838 0.838 0.838 0.838 0.047 0.047 0.047 0.047 0.047 ...}
#' \item{ easting    : num  1735759 1735759 1735759 1735759 1735759 ...}
#' \item{ observer   : chr  "Legolas" "Legolas" "Gollum" "Gollum" ...}
#' }
NULL

#' Middle Earth patch covariate data
#'
#' Most of what is known of Middle Earth (a.k.a. Arda) was documented by J.R.R.
#' Tolkien. Time is recorded in "Valian years", which measure the passage of
#' time since immortal spirits arrived on Arda.
#'
#' @name patch.data
#' @docType data
#' @keywords datasets
#' @format data-frame with 1869165 rows and 17 columns
#' \itemize{
#' \item{city            : num  0 0 0 0 0 0 0 0 0 0 ...}
#' \item{city_30km       : num  0 0 0 0 0 0 0 0 0 0 ...}
#' \item{hill            : num  1 1 1 1 1 1 0 0 0 0 ...}
#' \item{forest          : num  0 0 0 0 0 0 0 0 0 0 ...}
#' \item{lake            : num  0 0 0 0 0 0 0 0 0 0 ...}
#' \item{wetland         : num  0 0 0 0 0 0 0 0 0 0 ...}
#' \item{river           : num  0 0 0 0 0 0 0 0 0 0 ...}
#' \item{river_15km      : num  0 0 0 0 0 0 0 0 0 0 ...}
#' \item{forest_15km     : num  0 0 0 0 0 0 0 0 0 0 ...}
#' \item{wetland_15km    : num  0 0 0 0 0 0 0 0 0 0 ...}
#' \item{hill_15km       : num  0 0 0 0 0 0 0 0 0 0 ...}
#' \item{stonefields_15km: num  0 0 0 0 0 0 0 0 0 0 ...}
#' \item{northing        : num  1211319 1211319 1211319 1211319 1211319 ...}
#' \item{random          : num  0.0136 0.2065 0.2068 0.9523 0.056 ...}
#' \item{easting         : num  240759 241759 242759 243759 244759 ...}
#' \item{patchid         : num  1 2 3 4 5 6 7 8 9 10 ...}
#' \item{ID              : chr  "1" "2" "3" "4" ...}
#' }
NULL
