exampleBobcats <- function() {
#' Second RPresence example using real data, bobcats
#'
#'  Dummy function for help display
#'
#' @export
#' @seealso \code{\link{exampleGenpres}}, \code{\link{exampleBobcats}}, \code{\link{exampleSalamanders}}, \code{\link{exampleSkinks}}
#' @examples
#'
#' #   Read detection history data from csv file,
#' #     Note: "as.is=TRUE" prevents R from converting strings to factors.
#' csv<-read.csv(system.file("extdata/Bobcat.csv",package="RPresence"),as.is=TRUE)
#' #'
#' #   Create detection-history matrix variable, omitting 1st column (site name) in csv
#' dethist=csv[,2:8];  #  histories in cols 2-8
#'
#' #   Give names to rows of dethist matrix variable using site names
#' sitenames=csv[,1]  #  sitenames in 1st column
#' nsites=nrow(dethist)
#' #'
#' #   Get site covariate table: (Site covariates are covariates
#' #     that don't change over surveys.)
#' sitecov=as.data.frame(csv[,9:18])
#' #'
#' #   Get survey covariate - Observer (obs number for each survey)
#' obs <- csv[,19:25]
#'
#' #   Get survey covariate - Temperature (=temperature at time of survey)
#' temp <- csv[,26:32]
#'
#' #   Create data-frame from the 2 survey covariates.  Since we have 2 2-dimensional tables which we
#' #   need to convert into a single 2-dimensional table, we will collapse each covariate table
#' #   into a single column vector, then create a data-frame from the 2 columns.
#' surveycov=data.frame(obs=unlist(obs),
#'                      temp=unlist(temp))
#' #'
#' #   Create input "pao" object, for use with occMod function
#' data=createPao(data    =dethist,
#'                unitcov=sitecov,
#'                survcov=surveycov,
#'                title  ="Bobcat example",unitnames=sitenames)
#' #'
#' #    Run simplest model - psi(.)p(.) - constant occupancy and detection
#' psi_dot_p_dot = occMod(model=list(psi~1,p~1), data=data, type="so")
#' #    Print estimates of occupancy and detection...
#' print(unique(psi_dot_p_dot$real$psi))
#' print(unique(psi_dot_p_dot$real$p))
#' #'
#' #    Run model with detection as a function of the site-covariate, "Trail"
#' psi_dot_p_Trail = occMod(model=list(psi~1,p~Trail),data=data,type="so")
#' #    Print estimate of occupancy
#' print(unique(psi_dot_p_Trail$real$psi))
#' #    Print effect of Trail on detection...
#' print(psi_dot_p_Trail$beta$p)
#' #'
#' #    Run model with detection as an additive function of Trail and distance...
#' psi_dot_p_trail_dist=occMod(model=list(psi~1,p~Trail+Det_dist),data=data,type="so")
#' #'
#' #    Collect results of each model into a single list variable, "mods"
#' mods = list(psi_dot_p_dot, psi_dot_p_Trail, psi_dot_p_trail_dist)
#' #'
#' #     create AIC table of model results
#' results1<-createAicTable(mods)
#' #'
#' #    Print results summary table:
#' cat('bobcat example\n')
#' print(results1$table)
}
