exampleSalamanders <- function() {
#' Example intro script for RPresence using Salamander data from book.
#'
#'  Dummy function for help display
#'
#' @export
#' @seealso \code{\link{exampleGenpres}}, \code{\link{exampleBobcats}}, \code{\link{exampleSkinks}}
#' @examples
# ----  Exanple 3 - Single-season model with Salamander data (pg 135 in new occ. book) ----
#' #
#' #    Load a csv file with detection-histories
#' salmdr.csv<-read.csv(system.file("extdata/Blue_Ridge.csv",package="RPresence"),header=FALSE)
#'
#' #    Create PRESENCE input file object from csv
#' salmdr.data<-createPao(salmdr.csv,paoname="salmdr.pao")
#'
#' ## Fit some models
#' #    First, fit a model with survey-specific detection and constant occupancy: psi(.)p(t)
#' #    We can use the built-in survey covariate, "SURVEY" for this.
#' salmod1<-occMod(model=list(psi~1,p~SURVEY),data=salmdr.data,type="so")
#' #    Print estimates of occupancy and detection:
#' print(unique(salmod1$real$psi))
#' print(unique(salmod1$real$p))
#'
#' #    Next, we can fit a model where detection has one value for the first two
#' #    surveys, and another value for the rest of the surveys.  We'll need to
#' #    create a survey covariate and pass it to occMod as an argument.
#' #    Start by creating a matrix (nsites X nsurveys) of all zeros, then
#' #    set the last three columns to 1.
#' timecatgory = matrix(0,nrow=salmdr.data$nunits, ncol=salmdr.data$nsurveys)
#' timecatgory[,-1:-2]=1
#' #    Then, convert the matrix to a data-frame converted to a vector
#' srvycov = data.frame(timecat=as.vector(timecatgory))
#'
#' #    Fit the model, psi(.)p(timecat)...
#' salmod2<-occMod(model=list(psi~1,p~timecat),data=salmdr.data,type="so",
#'                 cov.list=list(p.cov=srvycov))
#' print(unique(salmod2$real$psi))
#' print(unique(salmod2$real$p))
#'
#' #    Create model results table
#' models<-list(salmod1,salmod2)
#' results<-createAicTable(models)
#'
#' #    print model results table
#' cat('Blue-Ridge example (table 4.2 in book)\n')
#' print(summary(results))
#'
}
