exampleWeta <- function() {
  #' Second RPresence example using real data, Giant Weta
  #'
  #'  Dummy function for help display
  #'
  #' @export
  #' @seealso \code{\link{exampleGenpres}}, \code{\link{exampleBobcats}}, \code{\link{exampleSalamanders}}, \code{\link{exampleSkinks}}
  #' @examples
  #'# load a PRESENCE data file
  #'
  #'wetadata<-read.csv(system.file("extdata/weta.csv",package="RPresence"),skip=1)
  #'
  #'#  get detection-histories in cols 1:5
  #'det_hist <- matrix(as.numeric(unlist(wetadata[,1:5])),ncol=5)
  #'
  #'# get site covariates (browsed,unbrowsed) in cols 7:8
  #'site_covs <- wetadata[,7:8]
  #'# convert site covariate into a factor (for nicer model output)
  #'Habitat=as.factor(c('unbrowsed','browsed')[site_covs$Browsed+1])
  #'
  #'# get survey covariate (observer) in cols 10-14
  #'obs <- wetadata[,10:14]
  #'obs[obs=='-']=NA            # convert missing data to NA
  #'
  #'#   create Presence input object, wetapao
  #'wetapao=createPao(data=det_hist,unitcov=data.frame(Habitat),
  #'                  survcov=data.frame(Obs=as.factor(unlist(obs))))
  #'
  #'## fit some models
  #'mod1<-occMod(model=list(psi~Habitat,p~SURVEY+Obs),data=wetapao,type="so")
  #'mod2<-occMod(model=list(psi~Habitat,p~Obs),data=wetapao,type="so")
  #'mod3<-occMod(model=list(psi~Habitat,p~SURVEY),data=wetapao,type="so")
  #'mod4<-occMod(model=list(psi~Habitat,p~1),data=wetapao,type="so")
  #'mod5<-occMod(model=list(psi~1,p~SURVEY+Obs),data=wetapao,type="so")
  #'mod6<-occMod(model=list(psi~1,p~Obs),data=wetapao,type="so")
  #'mod7<-occMod(model=list(psi~1,p~SURVEY),data=wetapao,type="so")
  #'mod8<-occMod(model=list(psi~1,p~1),data=wetapao,type="so")
  #'
  #'#  Now, let's show how to create a new site covariate and run a model...
  #'
  #'#  run model with new covariate for psi (covariate indicates group, where group=1
  #'#                                          if one of 1st 10 sites, group=0 otherwise)
  #'cov.list=list(psi.cov=data.frame(grp=(1:wetapao$nunits)<10))
  #'mod9<-occMod(model=list(psi~grp,p~1),cov.list=cov.list,data=wetapao,type="so")
  #'
  #'#  run model with new covariate for p   (covariate indicates if survey is one
  #'#                                         of the 1st 2 surveys)
  #'p12=rep(0,wetapao$nsurveys)
  #'p12[1:2]=1
  #'p12=rep(p12,each=wetapao$nunits)
  #'cov.list=list(p.cov=data.frame(frst2=p12))
  #'mod10<-occMod(model=list(psi~1,p~frst2),cov.list=cov.list,data=wetapao,type="so")
  #'#
  #'## create AIC table
  #'models<-list(mod1,mod2,mod3,mod4,mod5,mod6,mod7,mod8,mod9,mod10)
  #'results<-createAicTable(models)
  #'summary(results)
  #'
  #'## perform model averageing
  #'psi.ma<-modAvg(aic.tab=results,param="psi")
  #'p.ma<-modAvg(aic.tab=results,param="p")
  #'
  #' \dontrun{
  #'  mod1<-occMod(model=list(psi~Habitat,p~SURVEY+Obs),data=wetapao,type="so")
  #' }
}
