% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/genpres.R
\name{genpresEV2sp}
\alias{genpresEV2sp}
\title{generate expected value detection histories for multi-state models}
\usage{
genpresEV2sp(
  N = 100,
  K = 4,
  psi = c(0.8, 0.3, 0.7),
  p = c(0.6, 0.66, 0.7, 0.4, 0.5),
  gam = c(0, 0, 0),
  eps = c(0, 0, 0),
  SPS = 0,
  param = 0
)
}
\arguments{
\item{N}{number of sites}

\item{K}{number of surveys}

\item{psi}{probability of occupancy (psiA, psiBA, psiBa)}

\item{p}{probability of detection, given occupied state}

\item{gam}{prob. colonization (gamA, gamBA, gamBa)}

\item{eps}{prob. extinction (epsA, epsBA, epsBa)}

\item{SPS}{number of surveys per season}

\item{param}{0=default=psiA, psiBA, psiBa parm, 1=psiA,psiB,psiAB parm}
}
\value{
list(hst=det. history matrix, frq=vector of frequencies)
}
\description{
\code{genpresEV2sp} generates expected value detection history frequencies for
single or multi-season 2-species models.
}
\note{
This function generates at least 3^(K-1) detection-histories,
         so if K>6, it may take a very long time to run.
}
\examples{
\dontrun{
# generate expected value data for 2-species single-season model
x1=genpresEV2sp(N=100,K=4,
            psi=c(.8,.3,.7),            # psiA, psiBA, psiBa
            p=c(.6,.66,.7,.4,.5),       #  pA, pB, rA, rBA, rBa
            gam=c(0, 0, 0),             #  gamA, gamBA, gamBa
            eps=c(0, 0, 0),             #  epsA, epsBA, epsBa
            SPS=4)                      #  surveys per season

# generate expected value data for 2-species multi-season model
x2=genpresEV2sp(N=100,K=4,              # 100 sites, 4 surveys
            psi=c(.8,.3,.7),            # psiA, psiBA, psiBa
            p=c(.6,.66,.7,.4,.5),       #  pA, pB, rA, rBA, rBa
            gam=c(.1, .14, .17),        #  gamA, gamBA, gamBa
            eps=c(.2, .22, .24),        #  epsA, epsBA, epsBa
            SPS=2)                      #  surveys per season
}
}
\seealso{
\code{\link{genpresEV}},\code{\link{genpresSD}},
         \code{\link{genpresSDms}},  \code{\link{genpresEVms}}
}
