% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/genpres.R
\name{genpresEVmm}
\alias{genpresEVmm}
\title{generate expected value detection histories for multi-method model}
\usage{
genpresEVmm(
  N = 100,
  K = 4,
  psi = 0.75,
  p = c(0.4, 0.6),
  theta = 0.5,
  gamma = 0,
  epsilon = 0,
  methods = 2,
  SPS = NA
)
}
\arguments{
\item{N}{number of sites}

\item{K}{total number of detection events = number of seasons * methods * SPS}

\item{psi}{probability of occupancy}

\item{p}{probability of detection for each method}

\item{theta}{probability of local occupancy}

\item{gamma}{probability of colonization}

\item{epsilon}{probability of extinction}

\item{methods}{number of methods per survey}

\item{SPS}{number of surveys per season}
}
\value{
list(hst=det. history matrix, frq=vector of frequencies)
}
\description{
\code{genpresEVcd} generates expected value detection history frequencies for
single or multi-season correlated detection models
}
\note{
This function generates at least 2^K detection-histories, so if K>8, it may take a
      very long time to run.
}
\examples{
\dontrun{
   # generate expected value data for standard single-season model (no corr.det.)
hstfrq=genpresEVmm(N=1000, K=4, psi=.8, p=c(.3,.3), theta=1)
EVpao=createPao(hstfrq$hst,frq=hstfrq$frq)                  #  create pao file

   # generate expected value data for single-season multi-method model
hstfrq=genpresEVmm(N=1000, K=4, psi=.8, p=c(.3,.5), theta=.5, methods=2)
EVpao=createPao(hstfrq$hst,frq=hstfrq$frq)                  #  create pao file
}
}
\seealso{
\code{\link{genpresEVms}},\code{\link{genpresSD}},
         \code{\link{genpresSDms}}, \code{\link{genpresEV}}
}
