% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/genpres.R
\name{genpresSD}
\alias{genpresSD}
\title{generate simulated data (single or multi-season) detection histories}
\usage{
genpresSD(
  N = 100,
  K = 4,
  psi = 0.75,
  p = 0.4,
  fp = 0,
  b = 0,
  eps = 0,
  gam = 0,
  SPS = 0,
  cov = FALSE,
  seed = 0
)
}
\arguments{
\item{N}{number of sites}

\item{K}{number of surveys}

\item{psi}{probability of occupancy OR a pair of beta values}

\item{p}{probability of detection scaler or vector}

\item{fp}{probability of false detection}

\item{b}{probability of "sure" detection}

\item{eps}{probability of local extinction between seasons}

\item{gam}{probability of local colonization between seasons}

\item{SPS}{number of surveys per season}

\item{cov}{use parameters as beta values and generate covariates}

\item{seed}{seed number for random number generation}
}
\value{
list with detection-history matrix(hst) and
       vector of frequencies(frq)
}
\description{
\code{genpresSD} generates expected value detection history frequencies for
single or multi-season models
}
\details{
If cov is TRUE, the parameters psi,p,gam,eps should be vectors
constaining 2 values each.  The first is an intercept, and the
second is a covariate effect.  They will be used with randomly
generated site covariates (survey covarite for p) to produce
real parameter values for each site.
The site and survey covariates will be returned in the return object.
}
\examples{
\dontrun{
# generate simulated value data for standard single-season model
simdata=genpresSD(N=1000, K=4, psi=.8, p=.3)  # generate det. hists and freqs

SDpao=createPao(simdata$hst, frq=simdata$frq)                  #  create pao file

########################

   # generate simulated value data for multi-season model
simdata=genpresSD(N=1000, K=4, psi=.8, p=.3, eps=.2, gam=.1, SPS=2)  # generate det. hists and freqs

SDpao=createPao(simdata$hst, frq=simdata$frq,nsurveyseason=2)   #  create pao file

#########################

#generate simulated value data for single-season model with covariates

data=genpresSD(N=500, K=4,
              cov=TRUE,     # set to true to generate covariates
              psi=c(1, 2),  # beta values for psi : psi=exp(1+2*cov)/(1+exp(1+2*cov))
              p=c(-.5, 1))  # beta values for p: p=exp(-.5+1*cov)/(1+exp(-.5+1*cov))
#  note: unit covariate name will be "ucov" and values from std. normal distribution
#        survey covarite name is "scov" with range similar to ucov

#  create pao file
pao=createPao(data$hst,          # detection-history data
             unitcov=data$ucov,   #  unit(site) covariate data
             survcov=as.vector(unlist(data$scov))) # survey covariate data)

#  run standard single-season model with psi a function of unitcov
#    and p a function of survey covariate
m1=occMod(model=list(psi~ucov, p~survcov),data=pao)

#  create sequence of site covariate values from -2 to 2
newcov = data.frame(ucov=seq(-2,2,.1))
#  get predicted psi values for those covariate values
psi = predict(m1, newdata=newcov, param='psi')

#  plot psi versus range of site covariate values
#  with 95\% confidence intervals
plot(x=newcov$ucov, y=psi$est, type='l', main='psi with 95\% conf. intervals')
lines(x=newcov$ucov, y=psi$lower_0.95, lty=2)
lines(x=newcov$ucov, y=psi$upper_0.95, lty=2)
}
}
\seealso{
\code{\link{genpresSDms}},\code{\link{genpresEV}},
         \code{\link{genpresEVms}}
}
