% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/genpres.R
\name{genpresSDms}
\alias{genpresSDms}
\title{generate SIMULATED detection histories for multi-state model w/ psi/R parameterization.}
\usage{
genpresSDms(
  N = 100,
  K = 4,
  psi = 0.5,
  R = 0.8,
  p1 = 0.4,
  p2 = 0.3,
  dlta = 0.6,
  Cpsi = rep(0.5, 3),
  CR = rep(0.8, 3),
  SPS = 0,
  seed = 0
)
}
\arguments{
\item{N}{number of sites}

\item{K}{number of surveys}

\item{psi}{probability of occupancy}

\item{R}{probability of breeding (state=2), given occupancy}

\item{p1}{probability of detection, given occupied (state=1)}

\item{p2}{probability of detection, given occupied and breeding (state=2)}

\item{dlta}{probability of detecting breeding, given occupancy state=2}

\item{Cpsi}{conditional probability of occupancy, given previous state}

\item{CR}{conditional probability of breeding, given occupancy and previous state}

\item{SPS}{number of surveys per season}

\item{seed}{seed number for random number generation}
}
\value{
list(hst=det. history matrix, frq=vector of frequencies)
}
\description{
\code{genpresSDms} generates simulated detection histories for
single or multi-season multi-state models.
}
\examples{
\dontrun{
   # generate expected value data for standard single-season model (psi,R parameterization)
x1=genpresSDms(N=100,K=4,psi=.75,R=.8,p1=.4,p2=.3,dlta=.6,SPS=4)
}

N=500;K=4;psi=.75;R=.8;p1=.4;p2=.3;dlta=.6;Cpsi=c(.66,.1,.15);CR=c(.72,.77,0);SPS=2;seed=0
}
\seealso{
\code{\link{genpresSD}},\code{\link{genpresEV}},
         \code{\link{genpresEVms}}
}
