#include "SingAnal.h"
//****  Likelihood for joint modelling of 2 species from presence/absence data  ****//
#include <math.h>
#include <stdio.h>
#include <stdlib.h>

double TwoSpeciesMSLink(double *Params, int NPar) {
    double getParam(int param_num, int param_grp, int row, int site, int srvy, double *Params, int transf, int LinkFn);
    double invlogit(double x);
    int i, j, kk, tA, tB, seenA, seenB, seasn, srvy, survey, site, GAMBAAdifferent, iroweps1, irow; 
    int PrmyPeriods=SingSpec.PrmyPeriods, N=SingSpec.N, T=SingSpec.T, ip, Intervals, pdm=3;
    double loglike = 0, tmp=0, pA=0, pB=0, rA=0, rB=0, rAB=0, like0, likeA, likeB, likeAB, psiBA=0, psiBa=0, rBA=0, rBa=0;
    double lower, upper, phi, delta, alf, gam, prVec[4]={0,0,0,0}, ****xphi, tmpVec[4];
    double **psiA,**psiB,*psiAB,gamAb,gamAB,gamBaA,gamBaa,gamBAA,gamBAa,
                                 epsAb,epsAB,epsBaA,epsBaa,epsBAA,epsBAa;
    double epsA,epsB,gamA,gamB,x,sum,pnlty=0., rAnotB,rBnotA,K,psiAnotB,psiBnotA;
	double alfA,alfB,alfAB, betaA,betaB,betaAB,dltaA,dltaB,dltaAB,xiA,xiB,xiAB;
    
    Intervals=PrmyPeriods-1; iroweps1=Intervals*4+3;   // printf("TwoSpeciesMSLink altparm=%d\n",SingSpec.Alt_Param_Checked);
    psiA=new double*[N]; psiB=new double*[N]; psiAB=new double[N]; xphi=new double***[N];
    
    for (seasn=0; seasn<PrmyPeriods; seasn++) 
        for (kk=0; kk<N; kk++) SingSpec.psibar[seasn][kk][0]=SingSpec.psibar[seasn][kk][1]=0;
    
    for (site=0; site<N; site++) {  // loop through individual sites
		xphi[site]=new double**[PrmyPeriods];
		for (seasn=0; seasn<PrmyPeriods; seasn++) {
			xphi[site][seasn]=new double*[4]; for (i=0; i<4; i++) xphi[site][seasn][i]=new double[4];
		}
        psiA[site]=new double[PrmyPeriods];  psiB[site]=new double[PrmyPeriods];
        
        switch (SingSpec.Alt_Param_Checked) {
			
		case PSI_ALFA:  // newest parameterzation - psi-alfaA, psi-alfaB, psi-alfaAB
            alfA=getParam(0,0,0,site,0,Params,0,IDLnk);    //  from MacKenzie 2021 paper:
            alfB=getParam(1,0,1,site,0,Params,0,IDLnk);    //   alfA = mlogit(psiA & notB), alfB = mlogit(psiB & notA)
            alfAB=getParam(2,0,2,site,0,Params,0,IDLnk);    //   alfAB = mlogit(psiA & B)
            K=1+exp(alfA)+exp(alfB)+exp(alfA+alfB+alfAB);
            psiAnotB=exp(alfA)/K; psiBnotA=exp(alfB)/K; 
			psiAB[site]=exp(alfA+alfB+alfAB)/K;    
            psiA[site][0]=psiAnotB+psiAB[site]; psiB[site][0]=psiBnotA+psiAB[site];
			break;
			
		case PSIBA_ODDS_RATIO:    // newer parameterzation - psiA, psiBa, odds-ratio(psiBa:psiBA) 
			psiA[site][0]=getParam(0,0,0,site,0,Params,0,0);
            alf=getParam(1,0,1,site,0,Params,0,IDLnk);                 // (Alt_Param_Checked=2)
            gam=getParam(2,0,2,site,0,Params,0,IDLnk);
            psiBA=invlogit(alf); 
            psiBa=invlogit(alf+gam); 
            psiB[site][0]=psiA[site][0]*psiBA+(1-psiA[site][0])*psiBa; 
            psiAB[site]=psiA[site][0]*psiBA; 
			break;

        case PSIBA_PSIBa:  // new parameterzation - psiA, psiBa, psiBA(Alt_Param_Checked=1)
			psiA[site][0]=getParam(0,0,0,site,0,Params,0,0);
            psiBA=getParam(1,0,1,site,0,Params,0,0);
            psiBa=getParam(2,0,2,site,0,Params,0,0); 
            psiAB[site]=psiA[site][0]*psiBA;                //  Pr(occ by B) = Pr(occ by A)*pr(Occ by B | A present)
            psiB[site][0]=psiA[site][0]*psiBA+(1-psiA[site][0])*psiBa;  //    + Pr(not occ by A)*Pr(occ by B | A not present)
			break;
        case PSIB_PHI: //  orig parameterization - psiA,psiB,phi (Alt_Param_Checked=0)
			psiA[site][0]=getParam(0,0,0,site,0,Params,0,0);
            psiB[site][0]=getParam(1,0,1,site,0,Params,0,0); 
            phi=getParam(2,0,2,site,0,Params,1,expLnk);
			//  check if phi is in allowable bounds :  
			//            psiA+psiB-psiAB <= 1 
			//            psiA+psiB-psiA*psiB*phi <= 1
			//        so, phi >= (psiA+psiB-1) / (psiA*psiB)
			//     since phi=psiAB/(psiA*psiB) :
			//              phi < 1/(psiA*psiB)
			tmp=(psiA[site][0]+psiB[site][0]-1)/psiA[site][0]/psiB[site][0];  if (phi < tmp) pnlty=99999.;
			tmp=1/psiA[site][0]/psiB[site][0];                                 if (phi > tmp) pnlty=99999.;
            psiAB[site] = psiA[site][0]*psiB[site][0]*phi;
            // check whether value is in allowable bounds
            if (psiAB[site]<0.) { psiAB[site]=0.; pnlty=99999.;}
            if (psiAB[site]>1.) { psiAB[site]=1.; pnlty=99999.;}
		
		} // end switch/case statement
		//if (site==0) printf("%d>>%f %f %f\n",SingSpec.Alt_Param_Checked,psiA[site][0],psiB[site][0],psiAB[site]);
		
        if (SingSpec.UseNeighbor>0) {
            for (kk=0; kk<N; kk++) {
#ifdef neighbor2					
				i=SingSpec.neighbor_lst[kk][site]; if (i<0) break;
				SingSpec.psibar[0][kk][0]+=psiA[site][0]*SingSpec.neighbor_wgt[i];
				SingSpec.psibar[0][kk][1]+=psiB[site][0]*SingSpec.neighbor_wgt[i];
#else				
                if (SingSpec.neighbor[kk][site]>1) break;
                x=(double)SingSpec.neighbor[kk][site]*SingSpec.neighbor_wgt[site];
                SingSpec.psibar[0][kk][0]+=psiA[site][0]*x;
                SingSpec.psibar[0][kk][1]+=psiB[site][0]*x;
#endif
            }
		}
		if (site<0) printf("psiA,psiB,psiAB:%f %f %f\n",psiA[site][0],psiB[site][0],psiAB[site]);
    }   // end of site loop
    //  variables for option of gamBAA and gamBAa different in design matrix
    GAMBAAdifferent=(SingSpec.NrowsDM[1]>(Intervals*4+1));
    if (GAMBAAdifferent) iroweps1=Intervals*6+3;
	
	if (Intervals==0) pdm=1;

    for (seasn=0; seasn<Intervals; seasn++) {   //  loop by season so we can get avg psi over sites
        for (site=0; site<N; site++) {  // loop through individual sites
			
            switch (SingSpec.Alt_Param_Checked) {
				
			case PSI_ALFA:   //  newer parameterzation - psiA-alfa, psiB-alfa, psiAB-alfa) //  from MacKenzie et.al. 2021
                betaA= getParam(3+seasn,             1,seasn,            site,seasn,Params,0,IDLnk);
                betaB= getParam(3+seasn+1*Intervals, 1,seasn+1*Intervals,site,seasn,Params,0,IDLnk);
                betaAB=getParam(3+seasn+2*Intervals, 1,seasn+2*Intervals,site,seasn,Params,0,IDLnk);
                gamA=  getParam(3+seasn+3*Intervals, 1,seasn+3*Intervals,site,seasn,Params,0,IDLnk);
                gamB=  getParam(3+seasn+4*Intervals, 1,seasn+4*Intervals,site,seasn,Params,0,IDLnk);
                gamAB= getParam(3+seasn+5*Intervals, 1,seasn+5*Intervals,site,seasn,Params,0,IDLnk);
                dltaA= getParam(3+seasn+6*Intervals, 2,seasn+0*Intervals,site,seasn,Params,0,IDLnk);
                dltaB= getParam(3+seasn+7*Intervals, 2,seasn+1*Intervals,site,seasn,Params,0,IDLnk);
                dltaAB=getParam(3+seasn+8*Intervals, 2,seasn+2*Intervals,site,seasn,Params,0,IDLnk);
                xiA=   getParam(3+seasn+9*Intervals, 2,seasn+3*Intervals,site,seasn,Params,0,IDLnk);
                xiB=   getParam(3+seasn+10*Intervals,2,seasn+4*Intervals,site,seasn,Params,0,IDLnk);
                xiAB=  getParam(3+seasn+11*Intervals,2,seasn+5*Intervals,site,seasn,Params,0,IDLnk);
				xphi[site][seasn][0][1]=exp(betaA);       xphi[site][seasn][0][2]=exp(betaB);           xphi[site][seasn][0][3]=exp(betaA+betaB+betaAB);
				xphi[site][seasn][1][1]=exp(betaA+gamA);  xphi[site][seasn][1][2]=exp(betaB+gamB+xiB);  xphi[site][seasn][1][3]=exp(betaA+betaB+betaAB+gamA+gamB+gamAB);
				xphi[site][seasn][2][1]=exp(betaA+dltaA); xphi[site][seasn][2][2]=exp(betaB+dltaB);     xphi[site][seasn][2][3]=exp(betaA+betaB+betaAB+dltaA+dltaB+dltaAB);
				xphi[site][seasn][3][1]=exp(betaA+gamA+dltaA+xiA); 
				xphi[site][seasn][3][2]=exp(betaB+gamB+dltaB+xiB);
				xphi[site][seasn][3][3]=exp(betaA+betaB+betaAB+gamA+gamB+gamAB+dltaA+dltaB+dltaAB+xiA+xiB+xiAB); 
				for (i=0; i<4; i++) {
					for (K=j=1; j<4; j++) K+=xphi[site][seasn][i][j];
					for (j=1; j<4; j++) xphi[site][seasn][i][j]/=K;
				}
				break;
            case PSIBA_PSIBa:
			case PSIB_PHI: 
				gamAB =getParam(3+seasn,                 1,seasn,                site,seasn,Params,0,0);
				gamAb =getParam(3+seasn+Intervals      , 1,seasn+Intervals,site,seasn,Params,0,0);
				epsAB =getParam(iroweps1+seasn         , 2,seasn,                site,seasn,Params,0,0);
				epsAb =getParam(iroweps1+seasn+Intervals, 2,seasn+Intervals,site,seasn,Params,0,0);                
				irow=seasn+2*Intervals;
                
				gamBAA=gamBAa=getParam(3+irow,        1,irow,site,seasn,Params,0,0);
                epsBAA=epsBAa=getParam(iroweps1+irow, 2,irow,site,seasn,Params,0,0);
                if (GAMBAAdifferent) {
					irow+=Intervals;
					gamBAa=getParam(3+irow,        1,irow,site,seasn,Params,0,0);
					epsBAa=getParam(iroweps1+irow, 2,irow,site,seasn,Params,0,0);
				}
                irow+=Intervals;
                gamBaA=gamBaa=getParam(3+irow,        1,irow,site,seasn,Params,0,0);
                epsBaA=epsBaa=getParam(iroweps1+irow, 2,irow,site,seasn,Params,0,0);
                if (GAMBAAdifferent) {
					irow+=Intervals;
					gamBaa=getParam(3+irow,        1,irow,site,seasn,Params,0,0);
					epsBaa=getParam(iroweps1+irow, 2,irow,site,seasn,Params,0,0);
				}
			
				if (SingSpec.phi_insteadof_eps) {   //  if param name is 'phi' instead of 'eps'...
					epsAB=1-epsAB;  epsAb=1-epsAb; epsBAA=1-epsBAA; epsBAa=1-epsBAa; epsBaA=1-epsBaA; epsBaa=1-epsBaa;
				}
				epsA=psiB[site][seasn]*epsAB+(1-psiB[site][seasn])*epsAb;
				gamA=psiB[site][seasn]*gamAB+(1-psiB[site][seasn])*gamAb;
				psiA[site][seasn+1]=psiA[site][seasn]*(1-epsA)+(1-psiA[site][seasn])*gamA;
				
				epsB=    psiA[site][seasn] *((1-epsA)*epsBAA+epsA*epsBAa)+
					  (1-psiA[site][seasn])*(gamA*epsBaA+(1-gamA)*epsBaa);
				gamB=    psiA[site][seasn] *((1-epsA)*gamBAA+epsA*gamBAa)+
					  (1-psiA[site][seasn])*(gamA*gamBaA+(1-gamA)*gamBaa);
				psiB[site][seasn+1]=psiB[site][seasn]*(1-epsB)+(1-psiB[site][seasn])*gamB;
				if (SingSpec.UseNeighbor>0)
					for (kk=0; kk<N; kk++) {
#ifdef neighbor2					
						i=SingSpec.neighbor_lst[kk][site]; if (i<0) break;
						SingSpec.psibar[seasn+1][kk][0]+=psiA[site][seasn+1]*SingSpec.neighbor_wgt[i];
						SingSpec.psibar[seasn+1][kk][1]+=psiB[site][seasn+1]*SingSpec.neighbor_wgt[i];
#else						
						if (SingSpec.neighbor[kk][site]>1) break;
						x=(double)SingSpec.neighbor[kk][site]*SingSpec.neighbor_wgt[site];
						SingSpec.psibar[seasn+1][kk][0]+=psiA[site][seasn+1]*x;
						SingSpec.psibar[seasn+1][kk][1]+=psiB[site][seasn+1]*x;
#endif
					}
				//              transition matrix  
				//                  0                     A                    B                    AB
				//      0      (1-gamAb)*(1-gamBaa) gamAb*(1-gamBaA)    (1-gamAb)*gamBaa      gamAb*gamBaA
				//      A      epsAb*(1-gamBAa)    (1-epsAb)*(1-gamBAA)   epsAb*gamBAa      (1-epsAb)*gamBAA
				//      B      (1-gamAB)*epsBaa      gamAB*epsBaA     (1-gamAB)*(1-epsBaa)  gamAB*(1-epsBaA)
				//     AB      epsAB*epsBAa        (1-epsAB)*epsBAA     epsAB*(1-epsBAa)   (1-epsAB)*(1-epsBAA)
				
				if (SingSpec.Alt_Param_Checked!=PSIBA_ODDS_RATIO) { 
					xphi[site][seasn][0][1]=gamAb*(1-gamBaA);     xphi[site][seasn][0][2]=(1-gamAb)*gamBaa;     xphi[site][seasn][0][3]=gamAb*gamBaA;            
					xphi[site][seasn][1][1]=(1-epsAb)*(1-gamBAA); xphi[site][seasn][1][2]=epsAb*gamBAa;         xphi[site][seasn][1][3]=(1-epsAb)*gamBAA;        
					xphi[site][seasn][2][1]=gamAB*epsBaA;         xphi[site][seasn][2][2]=(1-gamAB)*(1-epsBaa); xphi[site][seasn][2][3]=gamAB*(1-epsBaA);        
					xphi[site][seasn][3][1]=(1-epsAB)*epsBAA;     xphi[site][seasn][3][2]=epsAB*(1-epsBAa);     xphi[site][seasn][3][3]=(1-epsAB)*(1-epsBAA); 
				}
			}   // end of switch/case statement
			for (i=0; i<4; i++) {
				xphi[site][seasn][i][0]=1-xphi[site][seasn][i][1]-xphi[site][seasn][i][2]-xphi[site][seasn][i][3];
			}
			
        } // end site loop
		
    }  // end seasn loop
	
    for (site=0; site<N; site++) {  // loop through individual sites
        likeA = psiA[site][0]-psiAB[site]; likeB = psiB[site][0]-psiAB[site]; 
        likeAB = psiAB[site]; like0 = 1-(likeA+likeB+likeAB); 
        
        // P[0]=pA  pB=pB  P[2]=pAB  P[3]=pAB'  P[4]=pA'B
        // new definition of detection probabilities
        // P[2] = rA = Pr(detect A | A & B present)
        // P[3] = rB = Pr(detect B | A & B present)
        // P[4] = rAB = Pr(detect A&B | A&B present) = pA x pB if independent
       
        survey=-1; ip=Intervals*8+3; if (GAMBAAdifferent) ip=Intervals*12+3;          //calculate pA's and pB's
       
        for (seasn=0; seasn<PrmyPeriods; seasn++) { 
            for (seenA=seenB=srvy=0; srvy<SingSpec.SecPeriods[seasn]; srvy++) { 
                if (SingSpec.Data[site][++survey]!=-1) {  //   if not missing data for survey ...
                    pA=rA=getParam(ip+survey,pdm,survey,site,survey,Params,0,0);
                    pB=rB=getParam(ip+survey+T,pdm,survey+T,site,survey,Params,0,0);
                    //    rBa = Pr(detect B | not detected A)         case is important!
                    //    rBA = Pr(detect B | detected A)
                    //    rA = Pr(detect A)   rB = Pr(detect B)   rAB = Pr(detect A and B)
                    //if(site==0)printf("pA=getparm(%d)=%f pB=%f rA=%f rB=%f\n",ip+survey,pA,pB,rA,rB);
                    switch (SingSpec.Alt_Param_Checked) {
					case PSIB_PHI: 
						rA=getParam(ip+survey+2*T,pdm,survey+2*T,site,survey,Params,0,0);
						rB=getParam(ip+survey+3*T,pdm,survey+3*T,site,survey,Params,0,0); 
                        delta=getParam(ip+survey+4*T,pdm,survey+4*T,site,survey,Params,1,0);
                        // check whether value is in allowable bounds
                        lower = (rA+rB-1)/(rA*rB); if (lower<0) lower=0;
                        upper = 1/rB; if (upper>(1/rA)) upper=1/rA;
                        if(delta < lower) return((fabs(delta-lower)+1)*1e10);
                        if(delta > upper) return((fabs(delta-upper)+1)*1e10);
                        rAB = rA*rB*delta;
						break;
                    case PSIBA_PSIBa: 
						rA=getParam(ip+survey+2*T,pdm,survey+2*T,site,survey,Params,0,0);
						rB=rBA=rBa=getParam(ip+survey+3*T,pdm,survey+3*T,site,survey,Params,0,0);
                        rBa=getParam(ip+survey+4*T,pdm,survey+4*T,site,survey,Params,0,0); 
						rAB=rA*rBA; rB=rA*rBA+(1-rA)*rBa;
						break;
                    case PSIBA_ODDS_RATIO: 
                        rBa=getParam(ip+survey+3*T,pdm,survey+3*T,site,survey,Params,0,0);
                        alf=getParam(ip+survey+3*T,pdm,survey+3*T,site,survey,Params,0,IDLnk);
                        gam=getParam(ip+survey+4*T,pdm,survey+4*T,site,survey,Params,0,IDLnk);  //  logit(rBA) = alpha + gamma 
                        rBA=invlogit(alf+gam); rB=rA*rBA+(1-rA)*rBa; rAB=rA*rBA; 
						break;
                    case PSI_ALFA:   //  newest parameterzation - psi-alfA, psi-alfB, psi-alfAB
						alfA=getParam(ip+survey+2*T,pdm,survey+2*T,site,0,Params,0,IDLnk);    //  from MacKenzie 2021 paper:
						alfB=getParam(ip+survey+3*T,pdm,survey+3*T,site,0,Params,0,IDLnk);    //   alfA = mlogit(psiA & notB), alfB = mlogit(psiB & notA)
						alfAB=getParam(ip+survey+4*T,pdm,survey+4*T,site,0,Params,0,IDLnk);    //   alfAB = mlogit(psiA & B)
						K=1+exp(alfA)+exp(alfB)+exp(alfA+alfB+alfAB);
						rAnotB=exp(alfA)/K; rBnotA=exp(alfB)/K; 
						rAB=exp(alfA+alfB+alfAB)/K;    
						rA=rAnotB+rAB; rB=rBnotA+rAB;
                    }
                    tA=tB=0;
                    if (SingSpec.Data[site][survey]==1 || SingSpec.Data[site][survey]==3) tA = 1;
                    if (SingSpec.Data[site][survey]==2 || SingSpec.Data[site][survey]==3) tB = 1;
                    if (SingSpec.Nstates==2) if (SingSpec.Data[site+N][survey]==1) tB = 1;
                    switch (tA + 2*tB) {
						case 0:     // neither detected
                        likeAB *= (1-rA-rB+rAB); likeA *= (1-pA); likeB *= (1-pB); break;
						case 1: likeAB *= rA-rAB; likeA *= pA; seenA = 1; break;   // A detected, not B
						case 2: likeAB *= rB-rAB; likeB *= pB; seenB = 1; break;   // not A, B detected
						case 3: likeAB *= rAB;  seenA = seenB = 1;  break;    // A and B detected
                    }   // end switch
                } // end if not missing..
            } // end survey=0..nsrvys/season
            
            prVec[0]=like0; prVec[1]=likeA; prVec[2]=likeB; prVec[3]=likeAB;
            
            switch(1*seenA + 2*seenB) {
				case 0:                      break;    //neither species detected  
				case 1: prVec[0]=prVec[2]=0; break;    // A seen, not B
				case 2: prVec[0]=prVec[1]=0; break;    // not A, B seen
				case 3: prVec[0]=prVec[1]=prVec[2]=0;          break;    // both seen
            }
   
            if (seasn<Intervals) {
                for (i=0; i<4; tmpVec[i++]=sum) { //  matrix mult 1x4 vector by 4x4 matrix
                    for (sum=j=0; j<4; j++) sum+=prVec[j]*xphi[site][seasn][j][i]; 
                }
                like0=tmpVec[0]; likeA=tmpVec[1]; likeB=tmpVec[2]; likeAB=tmpVec[3];
            }   // end if seasn<Intervals
        } // end for seasn=1..prmyPeriods
        tmp=prVec[0]+prVec[1]+prVec[2]+prVec[3]; 
		
        //printf(">>%d %f %f %f %f %f %f %f\n",site+1,10000*prVec[0],10000*prVec[1],10000*prVec[2],10000*prVec[3],
        //                  tmp*10000-SingSpec.det_hist_frq[site],tmp*10000,SingSpec.det_hist_frq[site]);
						  
        if (tmp < SingSpec.nearzero) tmp = SingSpec.nearzero; 
        if (tmp>1.0000000000001) { 
            printf("tmp>1(%22.20e) site=%d prVec=%f %f %f %f\n",tmp,site+1,prVec[0],prVec[1],prVec[2],prVec[3]); 
            exit(1);
        }
        
		loglike-=SingSpec.det_hist_frq[site]*log(tmp);
		SingSpec.expval[site]=10000*tmp;
		
		for (seasn=0; seasn<PrmyPeriods; seasn++) {
			for (i=0; i<4; i++) delete[] xphi[site][seasn][i];
			delete [] xphi[site][seasn];
		}
        delete [] psiA[site]; delete [] psiB[site]; delete [] xphi[site];
		
		
        
    } // end individual site loop
    delete [] psiA; delete [] psiB; delete [] psiAB; delete [] xphi;
    
    if (SingSpec.Verbose>2) printf("%d %f %f %f %f %f %f %f %f\n",SingSpec.ifn,loglike,pnlty,psiA[0][0],psiB[0][0],psiAB[0],Params[0],Params[1],Params[2]);
    //printf("%6d %16.4f\r",SingSpec.ifn,loglike);
	if (loglike != loglike) loglike=9e55;
    return(loglike+pnlty);
}
