#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
#include "SingAnal.h"

#define LENxpsi 5

int compute_xr(int site, int survey, int ip, double *Params, int pdm, double *xpsi) {
	double getParam(int param_num, int param_grp, int row, int site, int srvy, double *Params, int transf, int LinkFn);
	double alfaA,alfaB,alfaAB,K,rAnotB,rAB=0,rA=0,rBnotA,rB=0,rBA=0,rBa=0,alf,gam,phi,nu; 
	int T=SingSpec.T;
	
	switch (SingSpec.Alt_Param_Checked) {
	
		case PSIBA_PSIBa: 
			rA=getParam(ip+survey+2*T,pdm,survey+2*T,site,survey,Params,0,0);
			rB=getParam(ip+survey+3*T,pdm,survey+3*T,site,survey,Params,0,0); 				
			rBA=rB; rBa=getParam(ip+survey+4*T,pdm,survey+4*T,site,survey,Params,0,0);
			rAB=rA*rBA; rB=rA*rBA+(1-rA)*rBa;
			break;

		case PSIB_PHI: 
			rA=getParam(ip+survey+2*T,pdm,survey+2*T,site,survey,Params,0,0);
			rB=getParam(ip+survey+3*T,pdm,survey+3*T,site,survey,Params,0,0);
			gam=getParam(ip+survey+4*T,pdm,survey+4*T,site,survey,Params,0,expLnk);
			rAB=rA*rB*gam;
			rBA=rAB/rA;	rBa=(rB-rAB)/(1-rA);
			break;
						
		case PSIBA_ODDS_RATIO: 
			rA=getParam(ip+survey+3*T,pdm,survey+3*T,site,survey,Params,0,0);
			alf=getParam(ip+survey+3*T,pdm,survey+3*T,site,survey,Params,0,IDLnk);
			gam=getParam(ip+survey+4*T,pdm,survey+4*T,site,survey,Params,0,IDLnk);  //  logit(rBa) = alpha + gamma 
			rBA=1/(1+exp(-alf)); rBa=1/(1+exp(-alf-gam)); 
			rB=rA*rBA+(1-rA)*rBa; rAB=rA*rBA; 
			break;
			
		case PSI_ALFA:   //  newest parameterzation - psi-alfaA, psi-alfaB, psi-alfaAB
			alfaA=getParam(ip+survey+2*T,pdm,survey+2*T,site,0,Params,0,IDLnk);    //  from MacKenzie 2021 paper:
			alfaB=getParam(ip+survey+3*T,pdm,survey+3*T,site,0,Params,0,IDLnk);    //   alfaA = mlogit(psiA & notB), alfaB = mlogit(psiB & notA)
			alfaAB=getParam(ip+survey+4*T,pdm,survey+4*T,site,0,Params,0,IDLnk);    //   alfaAB = mlogit(psiA & B)
			K=1+exp(alfaA)+exp(alfaB)+exp(alfaA+alfaB+alfaAB);
			rAnotB=exp(alfaA)/K; rBnotA=exp(alfaB)/K; 
			rAB=exp(alfaA+alfaB+alfaAB)/K;    
			rA=rAnotB+rAB; rB=rBnotA+rAB;
			rBA=rAB/rA;	rBa=(rB-rAB)/(1-rA);
			break;
    }	
	phi=rAB/rA/rB; nu=(rBA/(1-rBA))/(rBa/(1-rBa));
	xpsi[0]=rA; xpsi[1]=rB; xpsi[2]=rAB; xpsi[3]=phi; xpsi[4]=nu;
	return(0);
}
					
int compute_xpsi(int site, int season, double *Params, double *xpsi) {
	double getParam(int param_num, int param_grp, int row, int site, int srvy, double *Params, int transf, int LinkFn);
	double alfaA,alfaB,alfaAB,K,psiAnotB,psiBnotA,psiAB=0,psiA=0,alf,gam,psiBA=0,psiBa=0,psiB=0,phi,nu;

	psiA=getParam(0,0,0,site,0,Params,0,0);
	
	switch (SingSpec.Alt_Param_Checked) {
	
	case PSIBA_PSIBa:  // default parameterzation - psiA, psiBa, psiBA(Alt_Param_Checked=1)
		psiBA=getParam(1,0,1,site,0,Params,0,0);
		psiBa=getParam(2,0,2,site,0,Params,0,0); 
		psiAB=psiA*psiBA;                //  Pr(occ by B) = Pr(occ by A)*pr(Occ by B | A present)
		psiB=psiAB+(1-psiA)*psiBa;  //    + Pr(not occ by A)*Pr(occ by B | A not present)
		break;
		
	case PSIB_PHI:    // original parameterzation - psiA, psiB, phi(SIF)
		psiB=getParam(1,0,1,site,0,Params,0,0);                 // (Alt_Param_Checked=0)
		phi =getParam(2,0,2,site,0,Params,0,expLnk);
		psiAB=psiA*psiB*phi;
		psiBA=psiAB/psiA; psiBa=(psiB-psiAB)/(1-psiA);
		break;

	case PSIBA_ODDS_RATIO:    // newer parameterzation - psiA, psiBa, odds-ratio(psiBa:psiBA) 
		alf=getParam(1,0,1,site,0,Params,0,IDLnk);                 // (Alt_Param_Checked=2)
		gam=getParam(2,0,2,site,0,Params,0,IDLnk);
		psiBA=1/(1+exp(-alf)); 
		psiBa=1/(1+exp(-alf-gam)); 
		psiB=psiA*psiBA+(1-psiA)*psiBa; 
		psiAB=psiA*psiBA;
		break;
		
	case PSI_ALFA:  // newest parameterzation - psi-alfaA, psi-alfaB, psi-alfaAB
		alfaA=getParam(0,0,0,site,0,Params,0,IDLnk);    //  from MacKenzie 2021 paper:
		alfaB=getParam(1,0,1,site,0,Params,0,IDLnk);    //   alfaA = mlogit(psiA & notB), alfaB = mlogit(psiB & notA)
		alfaAB=getParam(2,0,2,site,0,Params,0,IDLnk);    //   alfaAB = mlogit(psiA & B)
		K=1+exp(alfaA)+exp(alfaB)+exp(alfaA+alfaB+alfaAB);
		psiAnotB=exp(alfaA)/K; psiBnotA=exp(alfaB)/K; 
		psiAB=exp(alfaA+alfaB+alfaAB)/K;    
		psiA=psiAnotB+psiAB; psiB=psiBnotA+psiAB; 
		psiBA=psiAB/psiA; psiBa=(psiB-psiAB)/(1-psiA);
		break;
	
	} // end switch/case statement

	phi=psiAB/psiA/psiB; nu=(psiBA/(1-psiBA))/(psiBa/(1-psiBa));
	xpsi[0]=psiA; xpsi[1]=psiB; xpsi[2]=psiAB; xpsi[3]=phi; xpsi[4]=nu;
	return(0);
}			
int compute_xphi(int site, int season, int Intervals, int GAMBAAdifferent, double *Params, double *xphi) {
	double getParam(int param_num, int param_grp, int row, int site, int srvy, double *Params, int transf, int LinkFn);
	double betaA,betaB,betaAB,gamA,gamB,gamAB,dltaA,dltaB,dltaAB,xiA,xiB,xiAB,gamAb,epsAb,gamBAA,gamBAa,epsBAA,epsBAa,
		gamBaA,gamBaa,epsBaA,epsBaa,epsAB, K;
	int i,j,irow=0,iroweps1=Intervals*4+3;
	if (GAMBAAdifferent) iroweps1=Intervals*6+3;
	
	switch (SingSpec.Alt_Param_Checked) {
		
	case PSI_ALFA:   //  newer parameterzation - psiA-alfa, psiB-alfa, psiAB-alfa) //  from MacKenzie et.al. 2021
		betaA= getParam(3+season,             1,season,            site,season,Params,0,IDLnk);
		betaB= getParam(3+season+1*Intervals, 1,season+1*Intervals,site,season,Params,0,IDLnk);
		betaAB=getParam(3+season+2*Intervals, 1,season+2*Intervals,site,season,Params,0,IDLnk);
		gamA=  getParam(3+season+3*Intervals, 1,season+3*Intervals,site,season,Params,0,IDLnk);
		gamB=  getParam(3+season+4*Intervals, 1,season+4*Intervals,site,season,Params,0,IDLnk);
		gamAB= getParam(3+season+5*Intervals, 1,season+5*Intervals,site,season,Params,0,IDLnk);
		dltaA= getParam(3+season+6*Intervals, 2,season+0*Intervals,site,season,Params,0,IDLnk);
		dltaB= getParam(3+season+7*Intervals, 2,season+1*Intervals,site,season,Params,0,IDLnk);
		dltaAB=getParam(3+season+8*Intervals, 2,season+2*Intervals,site,season,Params,0,IDLnk);
		xiA=   getParam(3+season+9*Intervals, 2,season+3*Intervals,site,season,Params,0,IDLnk);
		xiB=   getParam(3+season+10*Intervals,2,season+4*Intervals,site,season,Params,0,IDLnk);
		xiAB=  getParam(3+season+11*Intervals,2,season+5*Intervals,site,season,Params,0,IDLnk);
		xphi[1]=exp(betaA);       xphi[2]=exp(betaB);           xphi[3]=exp(betaA+betaB+betaAB);
		xphi[5]=exp(betaA+gamA);  xphi[6]=exp(betaB+gamB+xiB);  xphi[7]=exp(betaA+betaB+betaAB+gamA+gamB+gamAB);
		xphi[9]=exp(betaA+dltaA); xphi[10]=exp(betaB+dltaB);     xphi[11]=exp(betaA+betaB+betaAB+dltaA+dltaB+dltaAB);
		xphi[13]=exp(betaA+gamA+dltaA+xiA); xphi[14]=exp(betaB+gamB+dltaB+xiB); xphi[15]=exp(betaA+betaB+betaAB+gamA+gamB+gamAB+dltaA+dltaB+dltaAB+xiA+xiB+xiAB); 
		for (i=0; i<4; i++) {
			for (K=j=1; j<4; j++) K+=xphi[i*4+j];
			for (j=1; j<4; j++) xphi[i*4+j]/=K;
		}
		break;
	case PSIBA_PSIBa:
	case PSIB_PHI: 
		gamAB =getParam(3+season,                 1,season,                site,season,Params,0,0);
		gamAb =getParam(3+season+Intervals      , 1,season+Intervals,site,season,Params,0,0);
		epsAB =getParam(iroweps1+season         , 2,season,                site,season,Params,0,0);
		epsAb =getParam(iroweps1+season+Intervals, 2,season+Intervals,site,season,Params,0,0);                
		irow=season+2*Intervals;
		
		gamBAA=gamBAa=getParam(3+irow,        1,irow,site,season,Params,0,0);
		epsBAA=epsBAa=getParam(iroweps1+irow, 2,irow,site,season,Params,0,0);
		if (GAMBAAdifferent) {
			irow+=Intervals;
			gamBAa=getParam(3+irow,        1,irow,site,season,Params,0,0);
			epsBAa=getParam(iroweps1+irow, 2,irow,site,season,Params,0,0);
		}
		irow+=Intervals;
		gamBaA=gamBaa=getParam(3+irow,        1,irow,site,season,Params,0,0);
		epsBaA=epsBaa=getParam(iroweps1+irow, 2,irow,site,season,Params,0,0);
		if (GAMBAAdifferent) {
			irow+=Intervals;
			gamBaa=getParam(3+irow,        1,irow,site,season,Params,0,0);
			epsBaa=getParam(iroweps1+irow, 2,irow,site,season,Params,0,0);
		}
	
		if (SingSpec.phi_insteadof_eps) {   //  if param name is 'phi' instead of 'eps'...
			epsAB=1-epsAB;  epsAb=1-epsAb; epsBAA=1-epsBAA; epsBAa=1-epsBAa; epsBaA=1-epsBaA; epsBaa=1-epsBaa;
		}
	
		if (SingSpec.Alt_Param_Checked!=PSIBA_ODDS_RATIO) { 
			xphi[1]=gamAb*(1-gamBaA);     xphi[2]=(1-gamAb)*gamBaa;     xphi[3]=gamAb*gamBaA;            
			xphi[5]=(1-epsAb)*(1-gamBAA); xphi[6]=epsAb*gamBAa;         xphi[7]=(1-epsAb)*gamBAA;        
			xphi[9]=gamAB*epsBaA;         xphi[10]=(1-gamAB)*(1-epsBaa); xphi[11]=gamAB*(1-epsBaA);        
			xphi[13]=(1-epsAB)*epsBAA;     xphi[14]=epsAB*(1-epsBAa);     xphi[15]=(1-epsAB)*(1-epsBAA); 
		}
	}   // end of switch/case statement
	for (i=0; i<4; i++) {
		xphi[i*4]=1-xphi[i*4+1]-xphi[i*4+2]-xphi[i*4+3];
	}	
	return(0);
}


void TwoSpecMultiSeason(int NBoot, char *s, int NPar, double *Params){
    double TwoSpeciesLink(double *Params, int NPar);
    double TwoSpeciesMSLink(double *Params, int NPar);
    void print_individual_estimates2(FILE *g, int realparmno, int pgrp, int istrt, int nrealparms, double **covar, double *Params, int linkfn, int fsite, int nsites);
    void prntBetas(double xxLike(double *p, int N), int NPar, double *Params, double *Work, double MaxLL, double **covar);
	void DoAmoeba( double *Params, int NPar, double (*funk)(double [], int), double xincr);
	int try_optmz_randiv(double (*xxFn)(double Params[], int npar), int NPar, double *Params, double *Work, double *Hess, double *MaxLL);
	double getParam(int param_num, int param_grp, int row, int site, int srvy, double *Params, int transf, int LinkFn);
  
    int i,j,ii, jj, ier=0, season, pdm=3,PrmyPeriods=SingSpec.PrmyPeriods, ppm1=SingSpec.PrmyPeriods-1, 
	    N=SingSpec.N, T=SingSpec.T,site,survey,ndec=4,Nmax=SingSpec.lmt;
    double *Hess, *Work, MaxLL, **covar, dA, dB, *naiveA, *naiveB, totsites=0;
    FILE *g;

	if (SingSpec.NrowsDM[2]<1) { 
		SingSpec.PrmyPeriods=PrmyPeriods=1; ppm1=PrmyPeriods-1; pdm=1; SingSpec.SecPeriods[0]=SingSpec.T;
	}
	
    g=SingSpec.g; naiveA=new double[PrmyPeriods+1]; naiveB=new double[PrmyPeriods+1];
	if (Nmax>N) Nmax=N;
	
    SingSpec.psibar=new double**[PrmyPeriods+1];
    for (ii=0; ii<=PrmyPeriods; ii++) {
		SingSpec.psibar[ii]=new double*[N]; naiveA[ii]=naiveB[ii]=0;
		for (jj=0; jj<N; jj++) SingSpec.psibar[ii][jj]=new double[2];
	}
    if (PrmyPeriods>1) fprintf(g,"Two Species, Multi-Season Model:\n---------------------------------\n");
	else fprintf(g,"Two Species, Single-Season Model:\n---------------------------------\n");
    if (SingSpec.Verbose) {
		if (PrmyPeriods>1) printf("Two Species, Multi-Season Model:\n---------------------------------\n");
		else printf("Two Species, Single-Season Model:\n---------------------------------\n");
		printf("alt_parm=%s\n",SingSpec.Realname[0][2]);
	}
	SingSpec.Alt_Param_Checked=0;
    if (strstr(SingSpec.Realname[0][2],"psiBa") != (void*)NULL || strstr(SingSpec.Realname[0][2],"psiB2") != (void*)NULL) {
        SingSpec.Alt_Param_Checked=1;
        fprintf(g,"-- alternate parameterization requested: psiA,psiBA,psiBa,pA,pB,rA,rBA,rBa\n");
    }
    if (strstr(SingSpec.Realname[0][2],"nu") != (void*)NULL) {
        SingSpec.Alt_Param_Checked=2;
        fprintf(g,"-- alternate parameterization requested: psiA,psiBa,nu,pA,pB,rA,rBa,rho\n");
    }
    if (strstr(SingSpec.Realname[0][2],"tau") != (void*)NULL) {
        SingSpec.Alt_Param_Checked=3;
        fprintf(g,"-- alternate parameterization requested: psiAb,psiBa,tau,pA,pB,rAb,rBa,ups\n");
    }
    if (strstr(SingSpec.Realname[0][2],"psi-alf") != (void*)NULL) {
        SingSpec.Alt_Param_Checked=4;
        fprintf(g,"-- alternate parameterization requested: psi-alfaAb, psi-alfaBa, psi-alfaAB, pA,pB,r-alfaAb,r-alfaBa,r-alfaAB\n");
    }
    if (SingSpec.Alt_Param_Checked==0) {
            fprintf(g,"-- standard parameterization requested: psiA,psiB,phi,pA,pB,rA,rB,delta\n");
    }
    if (SingSpec.Nstates==2) {   //  if data only contains 0's and 1's... then stacked input!
        SingSpec.N=N=N/2;SingSpec.NMiss/=2; 
        fprintf(g,"-- stacked input: 1st %d records=species A, last %d records=species B\n",N,N);
		for (site=0; site<N; site++) {
			for (season=j=0; season<PrmyPeriods; season++) {
				for (survey=dA=dB=0; survey<SingSpec.SecPeriods[season]; survey++,j++) {                              //  combined codes:  1=det of A only
					if (SingSpec.Data[site][j]>0) dA=SingSpec.det_hist_frq[site];
					if (SingSpec.Data[N+site][j]>0) dB=SingSpec.det_hist_frq[site];
					if (SingSpec.Data[site][j]>=0) {                           //                  2=det of B only
						if (SingSpec.Data[N+site][j]>=0)                        //                 3=det of  A & B  
							SingSpec.Data[site][j]=SingSpec.Data[site][j]+2*SingSpec.Data[N+site][j];
						else                                                              //              4=no det of A, B not sampled(missing)
							SingSpec.Data[site][j]+=4; //  A not det or det, B missing              5=det of A, B not sampled(missing)
					}                                                                      //             6=no det of B, A not sampled     
					else {   //  species A missing...                                                     7=det of B, A not sampled
						if (SingSpec.Data[N+site][j]>=0) 
							SingSpec.Data[site][j]=SingSpec.Data[N+site][j]+6;       //        -1=Neither A or B sampled
						else
							SingSpec.Data[site][j]=-1; //  both A and B missing					
					}
				}
				naiveA[season]+=dA; naiveB[season]+=dB;
			}
		}
    }
    else  {
		fprintf(g,"-- compressed input detected: 1=species A, 2=species B, 3=both\n");
		for (totsites=site=0; site<N; site++) {        //  compute naive occupancy for each species...
			totsites+=SingSpec.det_hist_frq[site];
			for (season=j=0; season<PrmyPeriods; season++) {
				for (survey=dA=dB=0; survey<SingSpec.SecPeriods[season]; survey++) {   
					i=SingSpec.Data[site][j++];
					if (i==1 || i==3 || i==5) dA=SingSpec.det_hist_frq[site];
					if (i==2 || i==3 || i==7) dB=SingSpec.det_hist_frq[site];
				}
				naiveA[season]+=dA; naiveB[season]+=dB;
			}
		}
	}

    fprintf(g,"\n%d Primary periods\n  Secondary periods:",PrmyPeriods);
    if (PrmyPeriods<1) {
        fprintf(g,"\nError: invalid number of primary periods (%d)\n",PrmyPeriods);
        exit(1);
    }
    for (ii=0; ii<PrmyPeriods; ii++) {
        fprintf(g," %d",SingSpec.SecPeriods[ii]);
        if (SingSpec.SecPeriods[ii]<1) {
            fprintf(g,"\nError: invalid number of secondary periods (%d)\n",SingSpec.SecPeriods[ii]);
            exit(1);
        }
    }

    fprintf(g,"\n\nNumber of input rows           = %d\n", N);
    fprintf(g,"Number of sites                = %4.0f\n", totsites);
    fprintf(g,"Number of sampling occasions   = %d\n", T);
    fprintf(g,"Number of missing observations = %d\n\n", SingSpec.NMiss);

	fprintf(g,"Naive occupancy for species A:");
	for (season=0; season<PrmyPeriods; season++) fprintf(g," %8.4f",naiveA[season]/totsites);
	fprintf(g,"\nNaive occupancy for species B:"); 
	for (season=0; season<PrmyPeriods; season++) fprintf(g," %8.4f",naiveB[season]/totsites);
	delete [] naiveA; delete [] naiveB;
	
	pdm=1+SingSpec.multiseason*2;  //  p design matrix number
	
    // try amoeba routine to get starting values

    fprintf(g,"\n\nModel:%s Par=%d\n",SingSpec.modname,NPar);

	if(SingSpec.UseAmoeba & (SingSpec.maxfn>1)) {
		if (SingSpec.multiseason) DoAmoeba(Params, NPar, TwoSpeciesMSLink, 1.0);
		else                      DoAmoeba(Params, NPar, TwoSpeciesLink, 1.0);
	}
	else MaxLL=TwoSpeciesMSLink(Params, NPar);
	
    Hess = new double[NPar*(NPar+1)/2+2]; Work = new double[3*NPar+2];
    covar = new double*[NPar]; for (ii=0; ii<NPar; ii++) covar[ii]=new double[NPar];
	
    if (SingSpec.Verbose) printf("calling optmiz...\n");
	if (SingSpec.multiseason) {
		if (SingSpec.maxfn>1) ier=try_optmz_randiv(TwoSpeciesMSLink, NPar, Params, Work, Hess, &MaxLL); 
		ii=ier;
	    prntBetas(TwoSpeciesMSLink,NPar, Params, Work, MaxLL, covar);
	}
	else {
		ier=try_optmz_randiv(TwoSpeciesLink, NPar, Params, Work, Hess, &MaxLL); ii=ier;
	    prntBetas(TwoSpeciesLink,NPar, Params, Work, MaxLL, covar);
	}
	delete[] Hess; delete[] Work; 
	int lf[4]={SingSpec.LinkFn,SingSpec.LinkFn,SingSpec.LinkFn,IDLnk};
	int lf2[4]={expLnk        ,SingSpec.LinkFn,expLnk         ,IDLnk};
    
	print_individual_estimates2(g,0,0,0,1,covar,Params,lf[SingSpec.Alt_Param_Checked],0,0); // PsiA
	print_individual_estimates2(g,1,0,1,1,covar,Params,lf[SingSpec.Alt_Param_Checked],0,0);  // psiB
	print_individual_estimates2(g,2,0,2,1,covar,Params,lf2[SingSpec.Alt_Param_Checked],0,0); // phi
	
	ii=SingSpec.NrowsDM[0]+SingSpec.multiseason*(SingSpec.NrowsDM[1]+SingSpec.NrowsDM[2]);
	
	print_individual_estimates2(g,ii,  pdm,0,T,    covar,Params,SingSpec.LinkFn,0,0);  // pA 
	print_individual_estimates2(g,ii+T,pdm,T,T,    covar,Params,SingSpec.LinkFn,0,0);   // pB 
	
	print_individual_estimates2(g,ii+T*2,pdm,2*T,T,covar,Params,lf[SingSpec.Alt_Param_Checked],0,0);  // rA
    print_individual_estimates2(g,ii+T*3,pdm,3*T,T,covar,Params,lf[SingSpec.Alt_Param_Checked],0,0); // rB
    print_individual_estimates2(g,ii+T*4,pdm,4*T,T,covar,Params,lf2[SingSpec.Alt_Param_Checked],0,0); // rB
	
	if (SingSpec.PrmyPeriods>1) {
		if (SingSpec.Alt_Param_Checked != PSI_ALFA) {
			ii=SingSpec.NrowsDM[0];
			print_individual_estimates2(g,ii       ,  1,0,ppm1,    covar,Params,SingSpec.LinkFn,0,0);  // gamAB
			print_individual_estimates2(g,ii+ppm1  ,  1,ppm1,ppm1,    covar,Params,SingSpec.LinkFn,0,0);  // gamAb
			print_individual_estimates2(g,ii+ppm1*2,  1,2*ppm1,ppm1,    covar,Params,SingSpec.LinkFn,0,0);  // gamBAA
			print_individual_estimates2(g,ii+ppm1*3,  1,3*ppm1,ppm1,    covar,Params,SingSpec.LinkFn,0,0);  // gamBAa
			print_individual_estimates2(g,ii+ppm1*4,  1,4*ppm1,ppm1,    covar,Params,SingSpec.LinkFn,0,0);  // gamBaa
			print_individual_estimates2(g,ii+ppm1*5,  1,5*ppm1,ppm1,    covar,Params,SingSpec.LinkFn,0,0);  // gamBaa

			ii+=SingSpec.NrowsDM[1];
			print_individual_estimates2(g,ii     ,    2,     0,ppm1,    covar,Params,SingSpec.LinkFn,0,0);  // epsAB
			print_individual_estimates2(g,ii+ppm1  ,  2,  ppm1,ppm1,    covar,Params,SingSpec.LinkFn,0,0);  // epsAb
			print_individual_estimates2(g,ii+ppm1*2,  2,2*ppm1,ppm1,    covar,Params,SingSpec.LinkFn,0,0);  // epsBAA
			print_individual_estimates2(g,ii+ppm1*3,  2,3*ppm1,ppm1,    covar,Params,SingSpec.LinkFn,0,0);  // epsBAa
			print_individual_estimates2(g,ii+ppm1*4,  2,4*ppm1,ppm1,    covar,Params,SingSpec.LinkFn,0,0);  // epsBaa
			print_individual_estimates2(g,ii+ppm1*5,  2,5*ppm1,ppm1,    covar,Params,SingSpec.LinkFn,0,0);  // epsBaa
		}
	}

	for (ii=0; ii<=PrmyPeriods; ii++) delete [] SingSpec.psibar[ii]; 
	delete [] SingSpec.psibar;
	
	char *lbl,*fmt2; lbl=new char[80]; fmt2=new char[80]; int kk,k;
	double eps=.1e-10, var;
	double **grad=new double*[NPar], **prd=new double*[NPar], *se=new double[16];

	for (i=0; i<NPar; i++) { grad[i]=new double[16]; prd[i]=new double[16]; }

    fprintf(g,"\n============================================================\n");
 	ii=snprintf(lbl,80,"%%%d.%df",ndec+4,ndec);
	ii=snprintf(fmt2,80,"%%-12s %%4d %%-16s:%s %s   %s -%s\n",lbl,lbl,lbl,lbl);
		
   //     print derived parameters... phi, dlta, psiB
		
	double *xpsi, *xpsi2; xpsi=new double[LENxpsi]; xpsi2=new double[LENxpsi];
	char v[]={"abAbaBAB"};
	int mxl=0; 
	for (i=0; i<N; i++) if ((int)strlen(SingSpec.sitename[i])>mxl) mxl=strlen(SingSpec.sitename[i]);
	ii=snprintf(fmt2,80,"%%-%d.%ds:",mxl,mxl);
	int Intervals=SingSpec.PrmyPeriods-1, GAMBAAdifferent=(SingSpec.NrowsDM[1]>(Intervals*4+1));
	
	fprintf(g,"\n    Derived initial occupancy parameters\n");
	fprintf(g,fmt2," ");
	fprintf(g,"  --psiA--    --psiB---     --psiAB-     ---phi--    ---nu---\n");
	fprintf(g,fmt2," ");
	fprintf(g,"  est   se     est   se     est   se     est   se     est    se  \n");

	for (site=0; site<Nmax; site++) {
		
		i=compute_xpsi(site, season, Params, xpsi);
		
		for (jj=0; jj<NPar; jj++) for (i=0; i<LENxpsi; i++) prd[jj][i]=0;
		for (jj=0; jj<NPar; jj++) {               //  Delta method
			Params[jj]+=eps;
			
			i=compute_xpsi(site, season, Params, xpsi2);
		
			for (i=0; i<LENxpsi; i++) grad[jj][i]=(xpsi2[i]-xpsi[i])/eps; 
			
			for (kk=0; kk<NPar; kk++) 
				for (i=0; i<LENxpsi; i++) prd[kk][i]+=grad[jj][i]*covar[jj][kk];  
			
			Params[jj]-=eps;
		}
		for (i=0; i<LENxpsi; i++) {
			for (var=jj=0; jj<NPar; jj++) 	var+=prd[jj][i]*grad[jj][i]; 
			se[i]=sqrt(var);
		}
		fprintf(g,fmt2,SingSpec.sitename[site]);
		if (xpsi[4]>99.999) xpsi[4]=99.999; 
		if (se[4]>99.999) se[4]=99.999;
		fprintf(g,"%6.3f%6.3f %6.3f%6.3f %6.3f%6.3f %6.3f%6.3f %6.3f %6.3f\n",
		   xpsi[0],se[0],xpsi[1],se[1],xpsi[2],se[2],xpsi[3],se[3],xpsi[4],se[4]);
	}

	if (PrmyPeriods>1) {
		fprintf(g,"\n    Derived parameter: PHI (Transition probabilities) by  season(S)\n   ");
		fprintf(g,fmt2," ");
		for (i=0; i<4; i++) 
			for (j=0; j<4; j++) 
				fprintf(g,"   %c%c-%c%c   ",v[i*2],v[i*2+1],v[j*2],v[j*2+1]); 
		fprintf(g,"\n");
		fprintf(g," S "); fprintf(g,fmt2," ");
		for (i=0; i<16; i++) fprintf(g," est   se  ");
		fprintf(g,"\n");
		double *xphi, *xphi2; xphi=new double[16]; xphi2=new double[16];
		
		for (season=0; season<Intervals; season++) {   //  loop by season so we can get avg psi over sites

			for (site=0; site<Nmax; site++) {  // loop through individual sites
				
				i=compute_xphi(site, season, Intervals, GAMBAAdifferent, Params, xphi);

				for (jj=0; jj<NPar; jj++) for (i=0; i<16; i++) prd[jj][i]=0;
				for (jj=0; jj<NPar; jj++) {
					Params[jj]+=eps; 
 
					i=compute_xphi(site, season, Intervals, GAMBAAdifferent, Params, xphi2);
					
					for (i=0; i<16; i++) {
						grad[jj][i]=(xphi2[i]-xphi[i])/eps;
						for (kk=0; kk<NPar; kk++) prd[kk][i]+=grad[jj][i]*covar[jj][kk];
					}
					Params[jj]-=eps;
				}
				for (i=0; i<16; i++) {
					for (var=jj=0; jj<NPar; jj++) var+=prd[jj][i]*grad[jj][i]; 
					se[i]=sqrt(var);
				}
				fprintf(g,"%2d ",season+1);
				fprintf(g,fmt2,SingSpec.sitename[site]);
				for (i=k=0; i<4; i++) {
					for (j=0; j<4; j++,k++) {
						fprintf(g,"%5.2f%5.2f ",xphi[k],se[k]);
					}
				}
				fprintf(g,"\n");
			}	
		}
		delete [] xphi; delete [] xphi2;
	}
	fprintf(g,"\n    Derived detection parameters by survey(S)\n    ");
	fprintf(g,fmt2," ");
	fprintf(g,"  ----rA-----  ----rB-----  ----rAB----  ---delta---  -----rho----\n  S ");
	fprintf(g,fmt2," ");
	fprintf(g,"  est     se    est     se    est     se    est     se    est     se  \n");
	int ip=(PrmyPeriods-1)*(8+4*GAMBAAdifferent)+3;
	
	for (survey=0; survey<T; survey++) { 
		for (site=0; site<Nmax; site++) {
			ii=survey*N+site;
			
			i=compute_xr(site, survey, ip, Params, pdm, xpsi);
		
			for (jj=0; jj<NPar; jj++) for (i=0; i<LENxpsi; i++) prd[jj][i]=0;
			for (jj=0; jj<NPar; jj++) {
				Params[jj]+=eps;
				
				i=compute_xr(site, survey, ip, Params, pdm, xpsi2);
			
				for (i=0; i<LENxpsi; i++) grad[jj][i]=(xpsi2[i]-xpsi[i])/eps; 
				
				for (kk=0; kk<NPar; kk++) 
					for (i=0; i<LENxpsi; i++) prd[kk][i]+=grad[jj][i]*covar[jj][kk];  
				
				Params[jj]-=eps;
			}
			for (i=0; i<LENxpsi; i++) {
				for (var=jj=0; jj<NPar; jj++) 	var+=prd[jj][i]*grad[jj][i]; 
				se[i]=sqrt(var);
			}
			fprintf(g,"%3d ",survey+1);
			fprintf(g,fmt2,SingSpec.sitename[site]);
			fprintf(g," %6.3f %6.3f %6.3f %6.3f %6.3f %6.3f %6.3f %6.3f %6.3f %6.3f\n",
			   xpsi[0],se[0],xpsi[1],se[1],xpsi[2],se[2],xpsi[3],se[3],xpsi[4],se[4]);
		}	
	}			
	delete [] xpsi; delete [] xpsi2;
	
	//printf("expected values:\n");
	//for (site=0; site<SingSpec.N; site++) printf("%d %f\n",site,SingSpec.expval[site]);
	
    // delete dynamic variables
	
	for (i=0; i<NPar; i++) { delete[] grad[i]; delete [] prd[i]; }
	delete[] grad; delete [] prd;
	delete[] se; 
	delete[] lbl; delete[] fmt2;   
    for (ii=0; ii<NPar; ii++) delete[] covar[ii];  
	delete[] covar; 
	if (SingSpec.Verbose) printf("exiting TwoSpecMultiSeason.cpp...\n");
}
