# test_msmods.R

test_that("multi-season models", {
  csv=read.csv('c:/users/jhines/onedri~1/hines/x/r/packages/rpresence/inst/extdata/do2sample.csv')
  rownames(csv)=csv[,1]
  do2pao=createPao(csv[,-1],nsurveyseason=rep(12,8))

  do2mod1 <- occMod(model=list(psi~1,gamma~-1+SEASON,epsilon~-1+SEASON,p~-1+SEASON),
                    data = do2pao, type = "do.1")
  v=print_one_site_estimates(do2mod1)
  #print(round(v,4))
  iv=do2mod1$beta$psi$est
  iv=c(iv,qlogis(do2mod1$derived$psi$est[seq(1,do2pao$nunits*(do2pao$nseasons-1),do2pao$nunits)]))
  iv=c(iv,do2mod1$beta$gamma$est,do2mod1$beta$p$est)

  do2mod3 <- occMod(model=list(psi~-1+SEASON,gamma~-1+SEASON,p~-1+SEASON),data = do2pao,
                    type = "do.2",initvals=iv)

  expect_equal(round(do2mod1$real$psi$est[1],2),0.31)
  expect_equal(round(do2mod3$real$psi$est[1],2),0.31)
})

test_that("multi-season models - EV data", {

  #cat('# --- MULTI-SEASON MODEL WITH EXPECTED-VALUE DATA ----\n')

  hstfrq=genpresEV(N=1000, K=4, psi=.8, p=.3, eps=.2, gam=.1, SPS=2)  #  generate expected-value data...
  EVpao=createPao(hstfrq$hst,frq=hstfrq$frq,nsurveyseason = rep(2,2))                  #  create pao file
  iv=qlogis(c(.68,.21,.32,.53));
  EVmod2<-occMod(model=list(psi~1,p~1,gamma~1,epsilon~1),data=EVpao,type="do.1",initvals=iv,maxfn=1000,threads=2)  # generate results
  #print_one_site_estimates(EVmod2)
  #  compare specified input parameters with estimated parameters...
  reslt=cbind(c(.8,.3,.2,.1),c(EVmod2$real$psi$est[1],EVmod2$real$p$est[1],EVmod2$real$epsilon$est[1],EVmod2$real$gamma$est[1]))
  rownames(reslt)=c('psi','p','epsilon','gamma'); colnames(reslt)=c('input_parameter','estimated_parameter')

  # -- MULTI-SEASON MODEL WITH EXPECTED-VALUE DATA ---
  expect_equal(round(EVmod2$aic,3),4166.165)
  expect_equal(round(EVmod2$real$psi$est[1],4),0.8)
  expect_equal(round(EVmod2$real$p$est[1],4),0.3)
  expect_equal(round(EVmod2$real$eps$est[1],4),0.2)
  expect_equal(round(EVmod2$real$gam$est[1],4),0.1)
  expect_equal(round(EVmod2$derived$psi$est[1],4),0.66)
  expect_equal(round(EVmod2$derived$psi$se[1],4),0.0469)
})

test_that("multi-season false-positive model", {
  #cat('# --- MULTI-SEASON FALSE-POSITIVE MODEL WITH EXPECTED-VALUE DATA ----\n')

  # generate expected value data for multi-season model with false positive detections
  hstfrq=genpresEV(N=100, K=6, psi=.75, p=.4, fp=0.3, b=0.6, eps=.2, gam=.1, SPS=2)  # generate det. hists and freqs
  EVpao=createPao(hstfrq$hst,frq=hstfrq$frq,nsurveyseason=rep(2,(ncol(hstfrq$hst)+1)/2))                  #  create pao file

  suppressWarnings(EVmod3<-occMod(model=list(psi~1,p11~1,p10~1,b~1,gamma~1,epsilon~1),data=EVpao,type="do.fp"))
  #  compare specified input parameters with estimated parameters...
  reslt=cbind(c(.75,.4,.3,.6,.2,.1,.1),
              c(EVmod3$real$psi$est[1],EVmod3$real$p11$est[1],EVmod3$real$p10$est[1],EVmod3$real$b$est[1],
                EVmod3$real$epsilon$est[1],EVmod3$real$gamma$est[c(1,EVpao$nunits+1)]))
  rownames(reslt)=c('psi','p11','p10','b','epsilon','gamma1','gamma2'); colnames(reslt)=c('input_parameter','estimated_parameter')
  sumerr=round(sum(reslt[,1]-reslt[,2]),2)

  expect_equal(round(reslt[1,2],2),0.75)
  expect_equal(round(reslt[2,2],2),0.40)
  expect_equal(round(reslt[3,2],2),0.30)
  expect_equal(round(reslt[4,2],2),0.60)
  expect_equal(round(reslt[5,2],2),0.20)
  expect_equal(round(reslt[6,2],2),0.10)
  expect_equal(round(reslt[7,2],2),0.10)

})
