rm(list=ls()); library(RPresence); setwd(Sys.getenv('TEMP'))
#===========================================================
t=t0=Sys.time()

# --- SIMPLE SINGLE-SEASON MODEL USING GENPRES TO GENERATE EXPECTED-VALUE DATA... ----\n')

data=genpresEVcd(K=4, psi=.75, p=.6);
a=createPao(data=data$hst, frq=data$frq)
ssm1<-occMod(data=a, type='so', model=list(psi~1,p~1),quiet=TRUE)
t2=Sys.time();  t=t2

# --- CORR-DETECTIONS (SINGLE-SEASON) MODEL USING EXPECTED-VALUE DATA FROM R genpresEVcd function... ----\n')

data=genpresEVcd(K=6, psi=.75, p=.4, theta=c(.3,.6))
CDpao=createPao(data=data$hst, frq=data$frq)
CDmod1<-occMod(model=list(psi~1,theta~PRIME,p~1,th0pi~1),data=CDpao,type="so.cd")  # generate results
v=round(rbind(unique(CDmod1$real$psi),unique(CDmod1$real$p),unique(CDmod1$real$theta),unique(CDmod1$real$th0pi)),4)
rownames(v)=c('psi','p','theta0','theta1','th0pi')
t2=Sys.time();  t=t2

# --- SINGLE-SEASON MODEL WITH SALAMANDER DATA (PG 135 IN NEW OCC. BOOK) ----\n')
# load a csv file with detection-histories
salmdr.csv<-read.csv(system.file("extdata/Blue_Ridge.csv",package="RPresence"),header=FALSE)

# Create PRESENCE input file object from csv
salmdr.data<-createPao(salmdr.csv,paoname="salmdr.pao")

## fit some models
salmod1<-occMod(model=list(psi~1,p~SURVEY),data=salmdr.data,type="so",VCoutopt="noreal")
salmod2<-occMod(model=list(psi~1,p~1)     ,data=salmdr.data,type="so")

## create AIC table
models<-list(salmod1,salmod2)
results<-createAicTable(models)




# --- CORR-DETECTIONS (MULTI-SEASON) MODEL USING EXPECTED VALUE DATA... ----\n')
#  generate expected-value data...
data=genpresEVcd(K=6, SPS=3, psi=.75, p=.4, theta=c(.3,.6), gamma=.2, epsilon=.1)

#  create RPresence input object, CDpao...
CDpao=createPao(data=data$hst, frq=data$frq, nsurveyseason = rep(ncol(data$hst)/2,2))

#  run corr-det model with all params constant...
MScdmod1<-occMod(model=list(psi~1,theta~PRIME,gamma~1,epsilon~1,p~1,th0pi~1),
                data=CDpao,type="do.1")

v=round(rbind(unique(MScdmod1$real$psi),unique(MScdmod1$real$p),
              unique(MScdmod1$real$gamma),unique(MScdmod1$real$epsilon),
              unique(MScdmod1$real$theta),unique(MScdmod1$real$th0pi)),4)
rownames(v)=c('psi','p','gamma','epsilon','theta0','theta1','th0pi')

# --- MULTI-STATE, SINGLE-SEASON MODEL (psi-R param) USING GENPRES TO GENERATE EXPECTED-VALUE DATA... ----\n')
hstfrq=genpresEVms(N=100,K=4,psi=.75,R=.8,p1=.4,p2=.3,dlta=.6,nstates=3)
pao=createPao(data=hstfrq$hst,frq=hstfrq$frq,nsurveyseason=4,paoname="tmp.pao")
msss1<-occMod(list(psi~1,R~1,p~STATE,delta~1),data=pao,type='do.ms.2')
#cat('Occupancy estimates:\n'); print(unique(msss1$real$psi))
#cat('Occupancy-state2 estimates:\n'); print(unique(msss1$real$R))
#cat('Detection estimates:\n'); print(unique(msss1$real$p))
#cat('Detection-state2 estimates:\n'); print(unique(msss1$real$delta));

# --- MULTI-STATE, MULTI-SEASON MODEL (psi-R param) USING GENPRES TO GENERATE EXPECTED-VALUE DATA... ----\n')
hstfrq=genpresEVms(N=100,K=4,psi=.75,R=.8, Cpsi=c(.66,.1,.15),CR=c(.72,.77,0),
                   p1=.4,p2=.3,dlta=.6,nstates=3,SPS=2)
pao=createPao(data=hstfrq$hst, frq=hstfrq$frq, nsurveyseason=rep(2,2))
psir<-occMod(list(psi~1,Cpsi~STATE,R~1,CR~STATE,p~STATE,delta~1),
          data=pao,type='do.ms.2')

#cat('Occupancy estimates:\n'); print(unique(psir$real$psi))
#cat('Occupancy-state2 estimates:\n'); print(unique(psir$real$R))
#cat('Detection estimates:\n'); print(unique(psir$real$p))
#cat('Detection-state2 estimates:\n'); print(unique(psir$real$delta))

# --- MULTI-STATE, MULTI-SEASON MODEL USING  EXP. VALUE DATA - PSI/PHI PARAMETERIZATION... ----\n')

# generate expected value data for multi-season model (phi parameterization)
K=6; nstates=3; p=matrix(0,nstates,nstates); p[2,2]<-p[3,2]<-p[3,3]<-.25; psi1=c(.167,.5,.333)
phi=rbind(c(.5,.333),c(.5,.333),c(.5,.333)); phi=cbind(1-rowSums(phi),phi)

x4=genpresEVms(N=100,K=K,nstates=3,psi1=psi1,phi=phi,p=p,SPS=2)  # generate exp. value data using RPresence function

data=createPao(x4$hst,frq=x4$frq,nsurveyseason=rep(2,K/2),paoname='tmp.pao')
fixed=data.frame(param=paste0('p21(',1:K,')'),value=rep(0,K))

ymods<-occMod(model=list(psi~STATE,phi~FROM_TO,p~OTSTATE),
             data=data,fixed=fixed,type="do.ms.1",threads=2)



#Testing results match expectations...
test_that("model results", {
  # --- SIMPLE SINGLE-SEASON MODEL USING GENPRES TO GENERATE EXPECTED-VALUE DATA... ----
  expect_equal(round(ssm1$real$psi$est[1],2),0.75)
  expect_equal(round(ssm1$real$p$est[1],2),0.60)

  # --- CORR-DETECTIONS (SINGLE-SEASON) MODEL USING EXPECTED-VALUE DATA FROM R genpresEVcd function... ---
  expect_equal(round(CDmod1$real$psi$est[1],3),0.75)
  expect_equal(round(CDmod1$real$p$est[1],3),0.4)
  expect_equal(round(CDmod1$real$theta$est[1],3),0.3)

  # --- CORR-DETECTIONS (MULTI-SEASON) MODEL USING EXPECTED VALUE DATA... ----
  expect_equal(round(MScdmod1$real$psi$est[1],3),0.75)
  expect_equal(round(MScdmod1$real$gamma$est[1],3),0.2)

  # ----  EXAMPLE 1 - SINGLE-SEASON MODEL WITH SALAMANDER DATA (PG 135 IN NEW OCC. BOOK) ---
  expect_equal(round(results$table$neg2ll[1],2),161.76)
  expect_equal(round(results$table$neg2ll[2],2),155.71)

  # ---- MULTI-STATE SINGLE-SEASON  EXP VALUE MODEL ----
  expect_equal(round(msss1$real$psi$est[1],2),0.75)
})

