# test_skinks.R

test_that("model results", {

  #  read detection-history data and site-covariate from csv file...
  csv<-read.csv(system.file('extdata/skinks.csv',package="RPresence"),na.strings="-")

  # create site covariate as a factor using "pasture" column in csv file
  habitat=c('Tussock','Pasture')[1+csv$Pasture]

  #  create presence input object
  data=createPao(data=csv[,2:16],
                 unitcov=data.frame(habitat=as.factor(habitat)),
                 nsurveyseason=rep(3,5))

  #  run model with seasonal gamma, eps, and p with p also function of covariate
  skm1<-occMod(model=list(psi~1,
                          gamma~SEASON,
                          epsilon~SEASON,
                          p~habitat+SEASON),
               data=data,type="do.1")

  # print results
  #print(unique(skm1$real$psi))
  #print(unique(skm1$real$p))
  #print(unique(skm1$real$gamma))
  #print(unique(skm1$real$epsilon))

  # print seasonal psi's
  #print(unique(skm1$derived$psi))

  #cat('# --- MULTI-SEASON MODEL WITH EXPECTED-VALUE DATA and unequal intervals ----\n')
  interval_lengths=c(5,7)/12; #interval_lengths=c(.5,.5)
  annual_eps=.25; annual_gam=0.1

  psi=.8; p=.3;
  eps=1-(1-annual_eps)^interval_lengths; gam=1-(1-annual_gam)^interval_lengths;
  #cat('gamma for intervals  :',gam,'\n')
  #cat('epsilon for intervals:',eps,'\n')

  hstfrq=genpresEV(N=1000, K=6, psi=psi, p=p, eps=eps, gam=gam, SPS=2)
  EVpao=createPao(hstfrq$hst,frq=hstfrq$frq,nsurveyseason = rep(2,3),intervals=interval_lengths)
  #iv=qlogis(c(.68,.21,.21,.32,.32,.53));
  iv=rep(0,6)

  EVmod2<-occMod(model=list(psi~1,p~1,gamma~SEASON,epsilon~SEASON),
                 data=EVpao,type="do.1",initvals=iv)
  #  compare specified input parameters with estimated parameters...
  reslt=cbind(c(psi,p,rep(annual_eps,2),rep(annual_gam,2)),
              c(EVmod2$real$psi$est[1],EVmod2$real$p$est[1],
                EVmod2$real$epsilon$est[c(1,65)],
                EVmod2$real$gamma$est[c(1,65)]))
  rownames(reslt)=c('psi','p','eps1','eps2','gam1','gam2');
  colnames(reslt)=c('input_parameter','estimated_parameter')
  #print(reslt)



  #  -- multi-season model using "Skinks" data ----
  expect_equal(round(skm1$aic,2),1774.55)  #  2996.497)
  expect_equal(round(sum(reslt[,1]-reslt[,2]),2),0)
})

